<?php
/**
* Unit test for the GaussianElimination::solve
*
* @see http://www.cs.princeton.edu/introcs/95linear/GaussianElimination.java.html
*
* Ported to PHP by Paul Meagher
* 
* @modified June 25/2007
* @modified March 25/2007
* @version 0.2
*/

// Step 1: Solve the linear equation. 
require_once "GaussianElimination.class.php";

$A = array(array(0, 1, 1),
        array(2, 4, -2),
        array(0, 3, 15));
     
$b = array(4, 2, 36);

$g = new GaussianElimination;

$x = $g->solve($A, $b);

// Step 2: Test whether computed and expected solution vectors are the same.

// define expected solution vector
$expected = array(-1.0, 2.0, 2.0);

// tallys used for unit testing
$expected_success = 0;
$expected_failure = 0;

$n = count($x);

for ($i=0; $i<$n; $i++) {
  // print solution vector component
  echo $x[$i] . " | " . $expected[$i] 
    . " " . ((abs($x[$i]-$expected[$i])<0.00001) ? "Ok": "Failed") . " <br />\n";
} 

echo "Test of <code>GaussianElimination::solve</code> method ... "; 

// The solve method passes the test if all elements of the computed 
// solution vector match the expected solution vector
if ($expected_success == $n){
  echo "<font color='red'><b>passed</b></font>\n";
}
else {
  echo "<font color='red'><b>failed</b></font>\n";
}

